# -*- coding: utf-8 -*-
import os
import sqlite3
from datetime import datetime

import psycopg2
from dotenv import load_dotenv
from psycopg2 import Error
from psycopg2.extras import DictCursor

load_dotenv(os.environ.get('DOTENV_FILE', '.env'))
con = psycopg2.connect(os.environ['DATABASE_URI'])
cur = con.cursor(cursor_factory=DictCursor)

old = sqlite3.connect(os.path.join('migrate', 'old.db'))
old.row_factory = sqlite3.Row
old_cur = old.cursor()


def migrate_mcmaniacs():
    with open('migrate/mcmaniacs.txt', 'r') as fp:
        for m in fp:
            try:
                cur.execute('''
                insert into
                  mcmaniacs (item)
                values
                  (%s)
                ''', [m.strip()])
                con.commit()
            except Error as ex:
                print(ex)
                con.rollback()


def migrate_kills():
    with open('migrate/kills.txt', 'r') as fp:
        for m in fp:
            try:
                cur.execute('''
                insert into
                  kills (item)
                values
                  (%s)
                ''', [m.replace('{user}', '{nick}').strip()])
                con.commit()
            except Error as ex:
                print(ex)
                con.rollback()


def migrate_yiffs():
    with open('migrate/yiffs.txt', 'r') as fp:
        for m in fp:
            try:
                cur.execute('''
                insert into
                  yiffs (item)
                values
                  (%s)
                ''', [m.replace('{user}', '{nick}').strip()])
                con.commit()
            except Error as ex:
                print(ex)
                con.rollback()


def migrate_quotes():
    old_cur.execute('''
    select
      *
    from
      quote
    ''')

    for q in old_cur.fetchall():
        try:
            cur.execute('''
            insert into
              quotes (nick, item, channel, created_by, created_at)
            values
              (%s, %s, %s, %s, %s)
            ''', [q['nick'].strip(),
                  q['msg'].strip(),
                  q['chan'].strip(),
                  q['add_nick'].strip(),
                  datetime.fromtimestamp(q['time'])])
            con.commit()
        except Error as ex:
            print(ex)
            con.rollback()


def migrate_seens():
    old_cur.execute('''
    select
      *
    from
      seen
    ''')

    seens = {}
    for s in old_cur.fetchall():
        nick = s['name'].strip()
        s = [nick,
             s['host'].strip(),
             s['chan'].strip(),
             s['quote'].strip(),
             s['time']]

        if nick not in seens or s[4] > seens[nick][4]:
            seens[nick] = s

    for s in seens.values():
        s[4] = datetime.fromtimestamp(s[4])

        try:
            cur.execute('''
            insert into
              seens (nick, host, channel, message, seen_at)
            values
              (%s, %s, %s, %s, %s)
            ''', s)
            con.commit()
        except Error as ex:
            print(ex)
            con.rollback()


def migrate_users():
    old_cur.execute('''
    select
      *
    from
      users
    ''')

    for u in old_cur.fetchall():
        husbando = u['husbando'].strip() if u['husbando'] else None
        waifu = u['waifu'].strip() if u['waifu'] else None
        fines = u['fines'] or None

        if husbando or waifu or fines:
            try:
                cur.execute('''
                insert into
                  users (nick, host, husbando, waifu, fines)
                values
                  (%s, %s, %s, %s, %s)
                ''', [u['nick'].strip(),
                      u['mask'].strip() if u['mask'] else None,
                      husbando,
                      waifu,
                      fines])
                con.commit()
            except Error as ex:
                print(ex)
                con.rollback()


migrate_kills()
migrate_yiffs()
migrate_mcmaniacs()
migrate_quotes()
migrate_seens()
migrate_users()
