# -*- coding: utf-8 -*-
import irc3
import requests
from docopt import Dict as DocOptDict
from irc3.plugins.command import command
from irc3.utils import IrcString

from . import Plugin


@irc3.plugin
class Weather(Plugin):
    requires = ['irc3.plugins.command']

    URL = 'https://query.yahooapis.com/v1/public/yql?format=json&q=' \
          'select * from weather.forecast where u="c" and woeid in ' \
          '(select woeid from geo.places(1) where text="{}")'

    @command
    def weather(self, mask: IrcString, target: IrcString, args: DocOptDict):
        """Gets the weather from Yahoo weather API.

        %%weather <location>...
        """
        req = requests.get(self.URL.format(' '.join(args['<location>'])))
        data = req.json()
        if 'error' in data:
            return '[Weather] Location not found'
        res = data['query']['results']['channel']
        return '[Weather] {city}, {region}, {country}: {temp}°{unit_temp} ' \
               '{text}, {direction} {speed} {unit_speed}' \
            .format(city=res['location']['city'],
                    region=res['location']['region'].strip(),
                    country=res['location']['country'],
                    temp=res['item']['condition']['temp'],
                    text=res['item']['condition']['text'],
                    direction='↑↗→↘↓↙←↖'[round(int(res['wind']['direction'])
                                               / 45) % 8],
                    speed=res['wind']['speed'],
                    unit_temp=res['units']['temperature'],
                    unit_speed=res['units']['speed'])
